abacusai.document_store_import — AbacusAI documentation

# `abacusai.document_store_import`

## Module Contents

### Classes

`DocumentStoreImport` | A document store import

class abacusai.document_store_import.DocumentStoreImport(client, documentStoreImportId=None, documentStoreId=None, importingStartedAt=None, status=None, error=None, documentsImported=None, documentsSkipped=None, uploadId=None, replaceExistingFiles=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A document store import

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - documentStoreImportId (str) – The unique identifier of the import

    - documentStoreId (str) – The unique identifier of the notebook.

    - importingStartedAt (str) – The timestamp at which the notebook was created.

    - status (str) – The current status of the dataset version

    - error (str) – If status is FAILED, this field will be populated with an error.

    - documentsImported (int) – The number of documents in the document store

    - documentsSkipped (int) – The number of documents in the document store

    - uploadId (str) –

    - replaceExistingFiles (bool) – If false, documents that match the same key path in the document store will be skipped

  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict